aboutsummaryrefslogtreecommitdiff
path: root/src/common/dns_utils.h
diff options
context:
space:
mode:
Diffstat (limited to '')
-rw-r--r--src/common/dns_utils.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/src/common/dns_utils.h b/src/common/dns_utils.h
index ff54c1e07..e57e55861 100644
--- a/src/common/dns_utils.h
+++ b/src/common/dns_utils.h
@@ -82,15 +82,15 @@ public:
std::vector<std::string> get_ipv6(const std::string& url);
/**
- * @brief gets a TXT record from a DNS query for the supplied URL;
- * if no TXT record present returns an empty string.
+ * @brief gets all TXT records from a DNS query for the supplied URL;
+ * if no TXT record present returns an empty vector.
*
* @param url A string containing a URL to query for
*
* @return A string containing a TXT record; or an empty string
*/
// TODO: modify this to accomodate DNSSEC
- std::string get_txt_record(const std::string& url);
+ std::vector<std::string> get_txt_record(const std::string& url);
/**
* @brief Gets the singleton instance of DNSResolver
@@ -82,15 +82,15 @@ public:
* @param url A string containing a URL to query for
*
- * @return A string containing a TXT record; or an empty string
+ * @return A vector of strings containing a TXT record; or an empty vector
*/
// TODO: modify this to accomodate DNSSEC